package com.zhyc.module.biosafety.mapper;

import com.zhyc.module.biosafety.domain.SwUnit;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * 药品单位Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-11
 */
@Mapper
public interface SwUnitMapper 
{
    /**
     * 查询药品单位
     * 
     * @param id 药品单位主键
     * @return 药品单位
     */
    public SwUnit selectSwUnitById(Long id);

    /**
     * 查询药品单位列表
     * 
     * @param swUnit 药品单位
     * @return 药品单位集合
     */
    public List<SwUnit> selectSwUnitList(SwUnit swUnit);

    /**
     * 新增药品单位
     * 
     * @param swUnit 药品单位
     * @return 结果
     */
    public int insertSwUnit(SwUnit swUnit);

    /**
     * 修改药品单位
     * 
     * @param swUnit 药品单位
     * @return 结果
     */
    public int updateSwUnit(SwUnit swUnit);

    /**
     * 删除药品单位
     * 
     * @param id 药品单位主键
     * @return 结果
     */
    public int deleteSwUnitById(Long id);

    /**
     * 批量删除药品单位
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSwUnitByIds(Long[] ids);
}
