package com.zhyc.module.biosafety.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.zhyc.module.biosafety.domain.SwUnit;
import com.zhyc.module.biosafety.service.ISwUnitService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zhyc.common.annotation.Log;
import com.zhyc.common.core.controller.BaseController;
import com.zhyc.common.core.domain.AjaxResult;
import com.zhyc.common.enums.BusinessType;
import com.zhyc.common.utils.poi.ExcelUtil;
import com.zhyc.common.core.page.TableDataInfo;

/**
 * 药品单位Controller
 * 
 * @author ruoyi
 * @date 2025-07-11
 */
@RestController
@RequestMapping("/biosafety/unit")
public class SwUnitController extends BaseController
{
    @Autowired
    private ISwUnitService swUnitService;

    /**
     * 查询药品单位列表
     */
    @PreAuthorize("@ss.hasPermi('biosafety:unit:list')")
    @GetMapping("/list")
    public TableDataInfo list(SwUnit swUnit)
    {
        startPage();
        List<SwUnit> list = swUnitService.selectSwUnitList(swUnit);
        return getDataTable(list);
    }

    /**
     * 导出药品单位列表
     */
    @PreAuthorize("@ss.hasPermi('biosafety:unit:export')")
    @Log(title = "药品单位", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SwUnit swUnit)
    {
        List<SwUnit> list = swUnitService.selectSwUnitList(swUnit);
        ExcelUtil<SwUnit> util = new ExcelUtil<SwUnit>(SwUnit.class);
        util.exportExcel(response, list, "药品单位数据");
    }

    /**
     * 获取药品单位详细信息
     */
    @PreAuthorize("@ss.hasPermi('biosafety:unit:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(swUnitService.selectSwUnitById(id));
    }

    /**
     * 新增药品单位
     */
    @PreAuthorize("@ss.hasPermi('biosafety:unit:add')")
    @Log(title = "药品单位", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SwUnit swUnit)
    {
        return toAjax(swUnitService.insertSwUnit(swUnit));
    }

    /**
     * 修改药品单位
     */
    @PreAuthorize("@ss.hasPermi('biosafety:unit:edit')")
    @Log(title = "药品单位", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SwUnit swUnit)
    {
        return toAjax(swUnitService.updateSwUnit(swUnit));
    }

    /**
     * 删除药品单位
     */
    @PreAuthorize("@ss.hasPermi('biosafety:unit:remove')")
    @Log(title = "药品单位", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(swUnitService.deleteSwUnitByIds(ids));
    }
}
